==> yybbs-0.53.zip: yybbs/res.php <==
<?php
    include "../../mainfile.php";
    include XOOPS_ROOT_PATH."/header.php";

	require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";
   
    require_once "./class/global.php";
    require_once "./class/user.php";	// ɤ߹Ǥ
    
    require_once "exForm/Form.php";

    // ƥץ졼ȤΤΥ桼
    $user = new YYBBSUser($xoopsUser);
    $cookieUser = new YYBBSCookieUser();
    $cookieUser->getCookie();
    $user->cookieUser_=&$cookieUser;

	// ID Ф
	$id=exAbstractActionForm::getPositive($_REQUEST['id']);
	$mHandler=&YYBBS::getHandler('message');
	$message=&$mHandler->get($id);
	if(!is_object($message))
		redirect_header('index.php',1,"{$id}ϤʤʥꥯȤǤ");

	$bHandler=&YYBBS::getHandler('bbs');
	$bbs=&$bHandler->get($message->getVar('bbs_id'));
	if(!is_object($bbs))
		redirect_header('index.php',1,"ʥꥯȤǤ");

    // եΤ˥Ф
    $handler=&YYBBS::getHandler('icon');
    $icons=&$handler->getObjects(null,null,'priority');

	$message->load();	// 쥹ݥƤ


	// եͽѰդå򼨤󥹥󥹤κ
	$newpost=&$mHandler->create();
	$newpost->setVar('parent',$message->getVar('id'));
	$newpost->setVar('title','Re: '.$message->getVar('title','e'));
	$newpost->setDefault($user->cookieUser_);

	// ưŪʰν
	$tmp = explode("\n",$message->getVar('message','n'));
	$mes = "";
	foreach ( $tmp as $i ) {
		$mes .= "> ".$i."\n";
	}
	$newpost->setVar('message',$mes);

	// View
	$head_message = sprintf ( _MD_YYBBS_RESPONCE_HEADMES, $message->getVar('serial') );
	$xoopsTpl->assign('head_message', $head_message );

	$xoopsOption['template_main'] = 'yybbs_res.html';
	$xoopsTpl->assign('bbs',$bbs->getStructure());
	$xoopsTpl->assign('bbsUser',$user->getStructure());
	$xoopsTpl->assign('post',$newpost->getStructure('e'));
	$xoopsTpl->assign('item',$message->getStructure());
	foreach($icons as $icon){
		$xoopsTpl->append('icons',$icon->getStructure());
	}

	include XOOPS_ROOT_PATH."/footer.php";
?>

==> yybbs-0.54.zip: yybbs/res.php <==
<?php
    include "../../mainfile.php";
    include XOOPS_ROOT_PATH."/header.php";

	require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";
   
    require_once "./class/global.php";
    require_once "./class/user.php";	// ɤ߹Ǥ
    
    require_once "exForm/Form.php";

    // ƥץ졼ȤΤΥ桼
    $user = new YYBBSUser($xoopsUser);
    $cookieUser = new YYBBSCookieUser();
    $cookieUser->getCookie();
    $user->cookieUser_=&$cookieUser;

	// ID Ф
	$id=exAbstractActionForm::getPositive($_REQUEST['id']);
	$mHandler=&YYBBS::getHandler('message');
	$message=&$mHandler->get($id);
	if(!is_object($message))
		redirect_header('index.php',1,"{$id}ϤʤʥꥯȤǤ");

	$bHandler=&YYBBS::getHandler('bbs');
	$bbs=&$bHandler->get($message->getVar('bbs_id'));
	if(!is_object($bbs))
		redirect_header('index.php',1,"ʥꥯȤǤ");

    // եΤ˥Ф
    $handler=&YYBBS::getHandler('icon');
    $icons=&$handler->getObjects(null,null,'priority');

	$message->load();	// 쥹ݥƤ


	// եͽѰդå򼨤󥹥󥹤κ
    $post = $mHandler->create();
	$post->setVar('parent',$message->getVar('id'));
	$post->setVar('title','Re: '.$message->getVar('title','e'));
	$post->setDefault($user->cookieUser_);
    if(!strlen($post->getVar('col'))) {
    	$tmp=$bbs->getColorArray();
    	$post->setVar('col',$tmp[0]);
    }


	// ưŪʰν
	$tmp = explode("\n",$message->getVar('message','n'));
	$mes = "";
	foreach ( $tmp as $i ) {
		$mes .= "> ".$i."\n";
	}
	$post->setVar('message',$mes);

	// View
	$head_message = sprintf ( _MD_YYBBS_RESPONCE_HEADMES, $message->getVar('serial') );
	$xoopsTpl->assign('head_message', $head_message );

	$xoopsOption['template_main'] = 'yybbs_res.html';
	$xoopsTpl->assign('bbs',$bbs->getStructure());
	$xoopsTpl->assign('bbsUser',$user->getStructure());
	$xoopsTpl->assign('post',$post->getStructure('e'));
	$xoopsTpl->assign('item',$message->getStructure());
	foreach($icons as $icon){
		$xoopsTpl->append('icons',$icon->getStructure());
	}

	include XOOPS_ROOT_PATH."/footer.php";
?>
